# -*- coding:utf-8; eval: (blacken-mode) -*-

import logging
import contextlib


logger = logging.getLogger(__name__)


def _init_logging():
    import logging.config

    cfg = {
        "version": 1,
        "formatters": {
            "standard": {
                "format": "%(asctime)s %(name)s %(levelname)s: %(message)s",
            }
        },
        "handlers": {
            "default": {
                "class": "logging.StreamHandler",
                "formatter": "standard",
                "stream": "ext://sys.stdout",
            }
        },
        "loggers": {
            "usadelndsoc": {
                "handlers": ["default"],
                "level": "INFO",
                "propagate": True,
            },
        },
    }

    logging.config.dictConfig(cfg)


@contextlib.contextmanager
def with_log_level(level):
    old_level = int(logger.level)
    logger.setLevel(level)
    try:
        yield
    finally:
        logger.setLevel(old_level)


_init_logging()
del _init_logging, logging, contextlib
